<template>
  <div class="full-screen">
        <div id="map" ref="rootmap"></div>
        <sgis-layer-controller :preset="'warningPreset'"></sgis-layer-controller>
        <monitor-panel></monitor-panel>
  </div>
</template>

<script>
import 'leaflet/dist/leaflet.css'
import Sgis from '@src/Sgis'
import mapConfig from '@/conf/MapConfig'
import SgisLayerController from '@components/LayerController/LayerController'
import MonitorPanel from '@components/panel/MonitorPanel'
import { mapMutations, mapState } from 'vuex'

export default {
  name: 'MapTemplate',
  components: {SgisLayerController, MonitorPanel},
  datas:{
      ...mapState("/",{})
  },
  mounted(){
      this.$nextTick(() => {
          this.init()
      })
  },
  methods:{
      ...mapMutations({
        setMapObj: 'setMapObj',
        setLayerHelper: 'setLayerHelper'
      }),
      init() {
        const mapcontainer = this.$refs.rootmap
        this.mapObj = Sgis.initMap(mapcontainer)

        this.basemapHelper = Sgis.initBasemapsHelper(this.mapObj.map, this.mapObj.L) // 初始化基础底图助手
        this.basemapHelper.initBasemap(mapConfig, false) // 第二个参数，表示是否内网底图


        this.serviceLayerHelper = Sgis.initTileLayersHelper(this.mapObj.map, this.mapObj.L) // 初始化业务底图助手
        this.serviceLayerHelper.initServiceLayers(mapConfig)

        this.vectorLayerHelper = Sgis.initVectorLayersHelper(this.mapObj.map, this.mapObj.L) // 初始化动态要素图层助手
        this.vectorLayerHelper.initVectorLayers(mapConfig)

        this.setLayerHelper(this.vectorLayerHelper)
        return this.map
      }
  }
}
</script>

<style lang="less">

.full-screen{
    width: 100%;
    height: 100%;
    margin: 0;
    padding: 0;
    position: absolute;
  #map{
    height: 100%;
    width: 100%;
  }
}
</style>>
